function copy_sounds_for_pub_Osses2023c_to_SQAT
% function copy_sounds_for_pub_Osses2023c_to_SQAT
%
% After you have the SQAT toolbox in your computer (and you have initialised
%   it by running startup_SQAT.m), run this script, without arguments.
%
% The SQAT toolbox can be retrieved from: https://github.com/ggrecow/SQAT
%
% Reference:
% Osses, A., Felix Greco, G., and Merino-Martinez, R. (2023) Considerations
%   for the perceptual evaluation of steady-state and time vareying sounds 
%   using psychoacoustic metrics. Forum Acusticum.
%
% Author: Alejandro Osses
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dirs_to_move = {'1-Aircraft-fly-by', ...
                '2-Train-pass-by', ...
                '3-Hummer-resonances'};
            
bp = basepath_SQAT;

path_this_zenodo = [fileparts(mfilename('fullpath')) filesep];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bThey_exist = zeros([1 length(dirs_to_move)]);
for i = 1:length(dirs_to_move)
    if exist([path_this_zenodo dirs_to_move{i} filesep],'dir')
        bThey_exist(i) = 1;
    end
end
if sum(bThey_exist) ~= length(dirs_to_move)
    error('Not all the source directories seem to be on disk. Stopping here...')
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dir_sounds_publ = [bp 'sound_files' filesep 'publications' filesep];
if ~exist(dir_sounds_publ,'dir')
    mkdir(dir_sounds_publ);
end

dir_target =  [dir_sounds_publ 'pub_Osses2023c_Forum_Acusticum_SQAT' filesep];
if ~exist(dir_target,'dir')
    mkdir(dir_target);
end

for i = 1:length(dirs_to_move)
    dir_dataset_src = [path_this_zenodo dirs_to_move{i} filesep];
    dir_dataset_dst = [dir_target dirs_to_move{i} filesep];
    if exist(dir_dataset_dst,'dir')
        fprintf('%s.m: dir %s not copied. It seems to be on disk already, at:\n',mfilename,dirs_to_move{i});
        fprintf('\t%s\n',dir_dataset_dst);
    else
        % We proceed with the copy:
        copyfile(dir_dataset_src, dir_dataset_dst);
        
        fprintf('%s.m: directory was successfully copied:\n',mfilename);
        fprintf('\t%s\n',dir_dataset_dst);
    end
        
end